About
=====

Copying meetings from the calendar to the ITC system is a tedious task.
Furthermore, it would be nice if an event could already specify on which contract
it should be booked.

``adnitc`` adresses these problems. It allows to parse the information contained in
the comment field of an event and creates the corersponding ITC entries.

